==> qcad-3.32.3.4-3-aarch64.pkg.tar.xz: usr/lib/qcad/ts/qcadgui_et.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="et_EE">
<context>
    <name>RCadToolBar</name>
    <message>
        <location filename="../src/gui/RCadToolBar.cpp" line="+139"/>
        <source>Vertical/Horizontal</source>
        <translation type="unfinished">Vertikaalne/horisontaalne</translation>
    </message>
</context>
<context>
    <name>RCadToolBarPanel</name>
    <message>
        <location filename="../src/gui/RCadToolBarPanel.cpp" line="+23"/>
        <location line="+63"/>
        <source>Back</source>
        <translation type="unfinished">Tagasi</translation>
    </message>
</context>
<context>
    <name>RColorCombo</name>
    <message>
        <location filename="../src/gui/RColorCombo.cpp" line="+154"/>
        <source>Custom</source>
        <translation type="unfinished">Kohandatud</translation>
    </message>
</context>
<context>
    <name>REventHandler</name>
    <message>
        <location filename="../src/gui/REventHandler.cpp" line="+211"/>
        <source>Grid</source>
        <translation type="unfinished">Võrk</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>End</source>
        <translation type="unfinished">End</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>On Entity</source>
        <translation type="unfinished">Üksuse kohta</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Perpendicular</source>
        <translation type="unfinished">Ristkülikukujuline</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Tangential</source>
        <translation type="unfinished">Tangentsiaalne</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Center</source>
        <translation type="unfinished">Keskus</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Middle</source>
        <translation type="unfinished">Keskmine</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Intersection</source>
        <translation type="unfinished">Ristmik</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Reference</source>
        <translation type="unfinished">Viide</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Distance</source>
        <translation type="unfinished">Kaugus</translation>
    </message>
</context>
<context>
    <name>RMathLineEdit</name>
    <message>
        <location filename="../src/gui/RMathLineEdit.cpp" line="+188"/>
        <source>Invalid</source>
        <translation type="unfinished">Invaliidne</translation>
    </message>
</context>
</TS>

==> qcad-3.32.5.0-1-aarch64.pkg.tar.xz: usr/lib/qcad/ts/qcadgui_et.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="et_EE">
<context>
    <name>RCadToolBar</name>
    <message>
        <location filename="../src/gui/RCadToolBar.cpp" line="+139"/>
        <source>Vertical/Horizontal</source>
        <translation>Vertikaalne/horisontaalne</translation>
    </message>
</context>
<context>
    <name>RCadToolBarPanel</name>
    <message>
        <location filename="../src/gui/RCadToolBarPanel.cpp" line="+23"/>
        <location line="+63"/>
        <source>Back</source>
        <translation>Tagasi</translation>
    </message>
</context>
<context>
    <name>RColorCombo</name>
    <message>
        <location filename="../src/gui/RColorCombo.cpp" line="+154"/>
        <source>Custom</source>
        <translation>Kohandatud</translation>
    </message>
</context>
<context>
    <name>REventHandler</name>
    <message>
        <location filename="../src/gui/REventHandler.cpp" line="+211"/>
        <source>Grid</source>
        <translation>Võrk</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>End</source>
        <translation>Otspunkt</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>On Entity</source>
        <translation>Objektil</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Perpendicular</source>
        <translation>Risti</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Tangential</source>
        <translation>Tangentsiaalne</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Center</source>
        <translation>Keskus</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Middle</source>
        <translation>Keskpunkt</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Intersection</source>
        <translation>Lõikepunkt</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Reference</source>
        <translation>Viide</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Distance</source>
        <translation>Kaugus</translation>
    </message>
</context>
<context>
    <name>RMathLineEdit</name>
    <message>
        <location filename="../src/gui/RMathLineEdit.cpp" line="+188"/>
        <source>Invalid</source>
        <translation>Kehtetu</translation>
    </message>
</context>
</TS>
